"""
Generated RPC Client Package

Auto-generated - DO NOT EDIT
Generated by: django_cfg_rpc codegen
"""

from .client import RPCClient
from .logger import ClientLogger, ClientLoggerConfig
from .models import (
{% for model in models %}
    {{ model }},
{% endfor %}
)

__all__ = [
    'RPCClient',
    'ClientLogger',
    'ClientLoggerConfig',
{% for model in models %}
    '{{ model }}',
{% endfor %}
]
