/**
 * Generated TypeScript Types
 *
 * Auto-generated from Pydantic models - DO NOT EDIT
 * Generated by: django_cfg_rpc codegen
 */

{% if interfaces %}
{% for interface in interfaces %}
{{ interface }}

{% endfor %}
{% else %}
// No types generated (handlers use generic Dict[str, Any] for params/returns)
export {};
{% endif %}
